.. gspread-dataframe documentation master file, created by
   sphinx-quickstart on Fri Mar 10 22:46:18 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to gspread-dataframe's documentation!
=============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. include:: ../README.rst

Module Documentation - Version |version|
----------------------------------------

.. automodule:: gspread_dataframe
   :members: get_as_dataframe, set_with_dataframe

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
